@@ -1,5 +1,6 @@
 import sys
 import argparse
+import logging
 from pathlib import Path
 
 from graphviz_py.graphviz import execute_graphviz
@@ -8,8 +9,9 @@ from graphviz_py.project import Project
 
 parser = argparse.ArgumentParser(description='graphviz-py diagram builder')
 parser.add_argument('-v', '--version', action='version', version=f'{Project.name()} version: {Project.version()}')
+parser.add_argument('-d', '--debug', action='store_true', help='show debug information')
 parser.add_argument('-a', '--argument', action='append')
-parser.add_argument('files', type=Path, nargs=argparse.ZERO_OR_MORE, help='an integer for the accumulator')
+parser.add_argument('files', type=Path, nargs=argparse.ZERO_OR_MORE, help='the paths to the graphviz-py files')
 
 args, unknown = parser.parse_known_args()
 
@@ -17,6 +19,9 @@ args, unknown = parser.parse_known_args()
 def main(_=None):
     """Process command line arguments."""
 
+    if args.debug:
+        logging.getLogger().setLevel(logging.DEBUG)
+
     file_contents = []
     arguments = []
 
